<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pa">
<context>
    <name>LXQtSysStatColours</name>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="14"/>
        <source>System Statistics Colors</source>
        <translation>ਸਿਸਟਮ ਅੰਕੜੇ ਰੰਗ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="24"/>
        <source>Graph</source>
        <translation>ਗਰਾਫ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="30"/>
        <source>&amp;Grid</source>
        <translation>ਗਰਿੱਡ(&amp;G)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="40"/>
        <location filename="../lxqtsysstatcolours.ui" line="57"/>
        <location filename="../lxqtsysstatcolours.ui" line="73"/>
        <location filename="../lxqtsysstatcolours.ui" line="90"/>
        <location filename="../lxqtsysstatcolours.ui" line="117"/>
        <location filename="../lxqtsysstatcolours.ui" line="144"/>
        <location filename="../lxqtsysstatcolours.ui" line="151"/>
        <location filename="../lxqtsysstatcolours.ui" line="178"/>
        <location filename="../lxqtsysstatcolours.ui" line="205"/>
        <location filename="../lxqtsysstatcolours.ui" line="232"/>
        <location filename="../lxqtsysstatcolours.ui" line="239"/>
        <location filename="../lxqtsysstatcolours.ui" line="265"/>
        <location filename="../lxqtsysstatcolours.ui" line="282"/>
        <source>Change ...</source>
        <translation>ਬਦਲੋ ...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="47"/>
        <source>T&amp;itle</source>
        <translation>ਟਾਈਟਲ(&amp;i)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="67"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="80"/>
        <source>&amp;Nice</source>
        <translation>ਨਾਈਸ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="97"/>
        <source>Ot&amp;her</source>
        <translation>ਹੋਰ(&amp;h)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="107"/>
        <source>&amp;Frequency</source>
        <translation>ਫਰੀਕਿਉਂਸੀ(&amp;F)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="124"/>
        <source>S&amp;ystem</source>
        <translation>ਸਿਸਟਮ(&amp;y)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="134"/>
        <source>&amp;User</source>
        <translation>ਵਰਤੋਂਕਾਰ(&amp;U)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="172"/>
        <source>Memory</source>
        <translation>ਮੈਮੋਰੀ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="185"/>
        <source>Cache&amp;d</source>
        <translation>ਕੈਸ਼ ਕੀਤੀ(&amp;d)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="195"/>
        <source>S&amp;wap</source>
        <translation>ਸਵੈਪ(&amp;w)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="212"/>
        <source>&amp;Applications</source>
        <translation>ਐਪਲੀਕੇਸ਼ਨਾਂ(&amp;A)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="222"/>
        <source>&amp;Buffers</source>
        <translation>ਬਫ਼ਰ(&amp;B)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="249"/>
        <source>Network</source>
        <translation>ਨੈੱਟਵਰਕ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="255"/>
        <source>&amp;Received</source>
        <translation>ਮਿਲੇ(&amp;R)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatcolours.ui" line="272"/>
        <source>&amp;Transmitted</source>
        <translation>ਭੇਜੇ(&amp;T)</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatConfiguration</name>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="14"/>
        <source>System Statistics Settings</source>
        <translation>ਸਿਸਟਮ ਅੰਕੜੇ ਸੈਟਿੰਗਾਂ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="22"/>
        <source>Graph</source>
        <translation>ਗਰਾਫ਼</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="34"/>
        <source>&amp;Minimal size</source>
        <translation>ਘੱਟੋ-ਘੱਟ ਆਕਾਰ(&amp;M)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="44"/>
        <source>Update &amp;interval</source>
        <translation>ਅੱਪਡੇਟ ਕਰਨ ਦਾ ਸਮਾਂ(&amp;i)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="54"/>
        <source>&amp;Title</source>
        <translation>ਟਾਈਟਲ(&amp;T)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="64"/>
        <source>&amp;Grid lines</source>
        <translation>ਗਰਿੱਡ ਲਾਈਨਾਂ(&amp;G)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height if the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="83"/>
        <source> px</source>
        <translation> ਪਿਕਸਲ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="99"/>
        <source> s</source>
        <translation> ਸ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="124"/>
        <source>Data</source>
        <translation>ਡਾਟਾ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="149"/>
        <source>Use &amp;frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="207"/>
        <source>Ma&amp;ximum</source>
        <translation>ਵੱਧ ਤੋਂ ਵੱਧ(&amp;x)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="222"/>
        <source>XXX KBs</source>
        <translation>XXX KB</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="241"/>
        <source>Lo&amp;garithmic scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="248"/>
        <source> steps</source>
        <translation> ਪੜਾਅ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="286"/>
        <source>&amp;Source</source>
        <translation>ਸਰੋਤ(&amp;S)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="296"/>
        <source>T&amp;ype</source>
        <translation>ਕਿਸਮ(&amp;y)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="312"/>
        <source>Colors</source>
        <translation>ਰੰਗ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="327"/>
        <source>Use t&amp;heme colours</source>
        <translation>ਥੀਮ ਦੇ ਰੰਗ ਵਰਤੋਂ(&amp;h)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="337"/>
        <source>Use c&amp;ustom colours</source>
        <translation>ਕਸਟਮ ਰੰਗਾਂ ਨੂੰ ਵਰਤੋਂ(&amp;u)</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.ui" line="344"/>
        <source>Custom colour ...</source>
        <translation>ਕਸਟਮ ਰੰਗ ...</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="41"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="42"/>
        <source>Memory</source>
        <translation>ਮੈਮੋਰੀ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="43"/>
        <source>Network</source>
        <translation>ਨੈੱਟਵਰਕ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="54"/>
        <source>cpu</source>
        <translation>cpu</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="55"/>
        <source>cpu0</source>
        <translation>cpu0</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="56"/>
        <source>cpu1</source>
        <translation>cpu1</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="57"/>
        <source>cpu2</source>
        <translation>cpu2</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="58"/>
        <source>cpu3</source>
        <translation>cpu3</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="59"/>
        <source>cpu4</source>
        <translation>cpu4</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="60"/>
        <source>cpu5</source>
        <translation>cpu5</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="61"/>
        <source>cpu6</source>
        <translation>cpu6</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="62"/>
        <source>cpu7</source>
        <translation>cpu7</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="63"/>
        <source>cpu8</source>
        <translation>cpu8</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="64"/>
        <source>cpu9</source>
        <translation>cpu9</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="65"/>
        <source>cpu10</source>
        <translation>cpu10</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="66"/>
        <source>cpu11</source>
        <translation>cpu11</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="67"/>
        <source>cpu12</source>
        <translation>cpu12</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="68"/>
        <source>cpu13</source>
        <translation>cpu13</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="69"/>
        <source>cpu14</source>
        <translation>cpu14</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="70"/>
        <source>cpu15</source>
        <translation>cpu15</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="71"/>
        <source>cpu16</source>
        <translation>cpu16</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="72"/>
        <source>cpu17</source>
        <translation>cpu17</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="73"/>
        <source>cpu18</source>
        <translation>cpu18</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="74"/>
        <source>cpu19</source>
        <translation>cpu19</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="75"/>
        <source>cpu20</source>
        <translation>cpu20</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="76"/>
        <source>cpu21</source>
        <translation>cpu21</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="77"/>
        <source>cpu22</source>
        <translation>cpu22</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="78"/>
        <source>cpu23</source>
        <translation>cpu24</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="79"/>
        <source>memory</source>
        <translation>ਮੈਮੋਰੀ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstatconfiguration.cpp" line="80"/>
        <source>swap</source>
        <translation>ਸਵੈਪ</translation>
    </message>
</context>
<context>
    <name>LXQtSysStatContent</name>
    <message>
        <location filename="../lxqtsysstat.cpp" line="407"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: %5%</source>
        <comment>CPU tooltip information</comment>
        <translation>ਸਿਸਟਮ: %1%&lt;br&gt;user: %2%&lt;br&gt;ਨਾਈਸ: %3%&lt;br&gt;ਹੋਰ: %4%&lt;br&gt;ਫਰੀਕਿ: %5%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="456"/>
        <source>system: %1%&lt;br&gt;user: %2%&lt;br&gt;nice: %3%&lt;br&gt;other: %4%&lt;br&gt;freq: n/a</source>
        <comment>CPU tooltip information</comment>
        <translation>ਸਿਸਟਮ: %1%&lt;br&gt;user: %2%&lt;br&gt;ਨਾਈਸ: %3%&lt;br&gt;ਹੋਰ: %4%&lt;br&gt;ਫਰੀ: ਲਾਗੂ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="498"/>
        <source>apps: %1%&lt;br&gt;buffers: %2%&lt;br&gt;cached: %3%</source>
        <comment>Memory tooltip information</comment>
        <translation>ਐਪਾਂ: %1%&lt;br&gt;ਬਫ਼ਰ: %2%&lt;br&gt;ਕੈਸ਼: %3%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="532"/>
        <source>used: %1%</source>
        <comment>Swap tooltip information</comment>
        <translation>ਵਰਤੀ: %1%</translation>
    </message>
    <message>
        <location filename="../lxqtsysstat.cpp" line="562"/>
        <source>min: %1%&lt;br&gt;max: %2%</source>
        <comment>Network tooltip information</comment>
        <translation>ਘੱਟ: %1%&lt;br&gt;ਵੱਧ: %2%</translation>
    </message>
</context>
</TS>
